@@ -1,4 +1,4 @@
-from .qiwi_api import QiwiWrapper
+from .API import QiwiWrapper
 from .qiwi_maps import QiwiMaps
 
 __all__ = ('QiwiWrapper', 'QiwiMaps')
