@@ -1,17 +1,19 @@
 from .account import Account
 from .account_info import QiwiAccountInfo
 from .balance import Balance
-from .bill import Bill, BillError, RefundBill, Notification
+from .bill import Bill, BillError, RefundBill, Notification, P2PKeys
 from .identification import Identification
 from .limit import Limit
+from .other import CrossRate, FreePaymentDetailsFields, PaymentMethod
 from .partner import Partner
 from .payment_info import PaymentInfo
 from .polygon import Polygon
-from .qiwi_master import OrderDetails
+from .qiwi_master import OrderDetails, Card
 from .stats import Statistic
 from .terminal import Terminal
 from .transaction import Transaction
 from .webhooks import WebHookConfig, WebHook
+from .restriction import Restriction
 
 __all__ = (
     'QiwiAccountInfo',
@@ -31,5 +33,11 @@ __all__ = (
     'Partner',
     'WebHook',
     'WebHookConfig',
-    'Notification'
+    'Notification',
+    'P2PKeys',
+    'CrossRate',
+    'FreePaymentDetailsFields',
+    'PaymentMethod',
+    'Card',
+    'Restriction'
 )
