@@ -3,9 +3,8 @@ from typing import Optional, Union
 
 from pydantic import BaseModel, Field, Extra
 
-from glQiwiApi.core.mixins import BillMixin
+from glQiwiApi.core.core_mixins import BillMixin
 from glQiwiApi.types.basics import OptionalSum
-from glQiwiApi.utils.basics import custom_load
 
 
 class Customer(BaseModel):
@@ -37,16 +36,6 @@ class BillError(BaseModel):
     datetime: str = Field(alias="dateTime")
     trace_id: str = Field(alias="traceId")
 
-    class Config:
-        """ Pydantic config """
-        json_loads = custom_load
-
-        def __str__(self) -> str:
-            return f'Config class with loads={self.json_loads}'
-
-        def __repr__(self) -> str:
-            return self.__str__()
-
 
 class Bill(BaseModel, BillMixin):
     """ Object: Bill """
@@ -63,12 +52,10 @@ class Bill(BaseModel, BillMixin):
     customer: Optional[Customer] = None
 
     class Config:
-        """ Pydantic config """
-        json_loads = custom_load
         extra = Extra.allow
 
         def __str__(self) -> str:
-            return f'Config class with loads={self.json_loads}'
+            return "<Config pydantic model {Bill}>"
 
         def __repr__(self) -> str:
             return self.__str__()
@@ -97,16 +84,6 @@ class Notification(BaseModel):
     version: str = Field(..., alias="version")
     bill: Bill = Field(..., alias="bill")
 
-    class Config:
-        """ Pydantic config """
-        json_loads = custom_load
-
-        def __str__(self) -> str:
-            return f'Config class with loads={self.json_loads}'
-
-        def __repr__(self) -> str:
-            return self.__str__()
-
     def __str__(self) -> str:
         return f"#{self.bill.bill_id} {self.bill.amount} {self.bill.status} "
 
@@ -114,9 +91,15 @@ class Notification(BaseModel):
         return self.__str__()
 
 
+class P2PKeys(BaseModel):
+    public_key: str = Field(..., alias="PublicKey")
+    secret_key: str = Field(..., alias="SecretKey")
+
+
 __all__ = (
     'Bill',
     'BillError',
     'RefundBill',
-    'Notification'
+    'Notification',
+    'P2PKeys'
 )
