@@ -2,9 +2,7 @@ from datetime import datetime
 from enum import Enum
 from typing import Optional, Union, Dict, List, Any
 
-from pydantic import BaseModel, Field, Extra
-
-from glQiwiApi.utils.basics import custom_load
+from pydantic import BaseModel, Field
 
 
 class BalanceDetails(BaseModel):
@@ -79,16 +77,6 @@ class AccountInfo(BaseModel):
     - JCB.
     """
 
-    class Config:
-        """ Pydantic config """
-        json_loads = custom_load
-
-        def __str__(self) -> str:
-            return f'Config class with loads={self.json_loads}'
-
-        def __repr__(self) -> str:
-            return self.__str__()
-
 
 class OperationType(Enum):
     """
@@ -181,16 +169,6 @@ class Operation(BaseModel):
 
     details: Optional[Any] = None
 
-    class Config:
-        """ Pydantic config """
-        json_loads = custom_load
-
-        def __str__(self) -> str:
-            return f'Config class with loads={self.json_loads}'
-
-        def __repr__(self) -> str:
-            return self.__str__()
-
 
 class OperationDetails(BaseModel):
     """ object: OperationDetails """
@@ -203,13 +181,13 @@ class OperationDetails(BaseModel):
     amount: Optional[float] = None
     """Сумма операции (сумма списания со счета)."""
 
-    operation_date: Optional[str] = Field(..., alias="datetime")
+    operation_date: Optional[datetime] = Field(default=None, alias="datetime")
     """
     Дата и время совершения операции в формате строки
     в ISO формате с часовым поясом UTC.
     """
 
-    operation_type: Optional[str] = Field(..., alias="type")
+    operation_type: Optional[str] = Field(default=None, alias="type")
     """Тип операции. Возможные значения:
     payment-shop — исходящий платеж в магазин;
     outgoing-transfer — исходящий P2P-перевод любого типа;
@@ -335,16 +313,6 @@ class OperationDetails(BaseModel):
     Все прочие значения - техническая ошибка, повторите вызов метода позднее.
     """
 
-    class Config:
-        """ Pydantic config """
-        json_loads = custom_load
-
-        def __str__(self) -> str:
-            return f'Config class with loads={self.json_loads}'
-
-        def __repr__(self) -> str:
-            return self.__str__()
-
 
 class Wallet(BaseModel):
     """ object: Wallet """
@@ -416,16 +384,6 @@ class PreProcessPaymentResponse(BaseModel):
     account_unblock_uri: Optional[str] = None
     ext_action_uri: Optional[str] = None
 
-    class Config:
-        """ Pydantic config """
-        json_loads = custom_load
-
-        def __str__(self) -> str:
-            return f'Config class with loads={self.json_loads}'
-
-        def __repr__(self) -> str:
-            return self.__str__()
-
 
 class Payment(BaseModel):  # lgtm [py/missing-equals #
     """ object: Payment """
@@ -522,21 +480,10 @@ class Payment(BaseModel):  # lgtm [py/missing-equals #
     при передаче аргументов
     """
 
-    def initialize(self, protection_code: str) -> 'Payment':
+    def initialize(self, protection_code: Optional[str]) -> 'Payment':
         self.protection_code = protection_code
         return self
 
-    class Config:
-        """ Pydantic config """
-        json_loads = custom_load
-        extra = Extra.allow
-
-        def __str__(self) -> str:
-            return f'Config class with loads={self.json_loads}'
-
-        def __repr__(self) -> str:
-            return self.__str__()
-
 
 class IncomingTransaction(BaseModel):
     """ object: IncomingTransaction """
@@ -545,16 +492,6 @@ class IncomingTransaction(BaseModel):
     ext_action_uri: Optional[str] = None
     error: Optional[str] = None
 
-    class Config:
-        """ Pydantic config """
-        json_loads = custom_load
-
-        def __str__(self) -> str:
-            return f'Config class with loads={self.json_loads}'
-
-        def __repr__(self) -> str:
-            return self.__str__()
-
 
 __all__ = (
     'AccountInfo',
