@@ -6,11 +6,13 @@ import datetime
 import functools as ft
 import hashlib
 import hmac
+import pathlib
 import re
 import time
 from contextvars import ContextVar
 from copy import deepcopy
 
+import aiofiles
 import pytz
 from pydantic import ValidationError, BaseModel
 from pytz.reference import LocalTimezone
@@ -23,23 +25,6 @@ except (ModuleNotFoundError, ImportError):
 # Gets your local time zone
 Local = LocalTimezone()
 
-QIWI_MASTER = {
-    "id": str(int(time.time() * 1000)),
-    "sum": {
-        "amount": 2999,
-        "currency": "643"
-    },
-    "paymentMethod": {
-        "type": "Account",
-        "accountId": "643"
-    },
-    "comment": "test",
-    "fields": {
-        "account": "",
-        "vas_alias": "qvc-master"
-    }
-}
-
 
 def measure_time(func):
     """
@@ -199,11 +184,13 @@ def set_data_p2p_create(wrapped_data, amount, life_time, comment, theme_code,
     wrapped_data.json['amount']['value'] = str(amount)
     wrapped_data.json['comment'] = comment
     wrapped_data.json['expirationDateTime'] = life_time
-    if pay_source_filter in ['qw', 'card', 'mobile']:
+    if isinstance(pay_source_filter, list):
+        source_filters = " ".join(pay_source_filter).replace(" ", ",")
         wrapped_data.json['customFields'][
-            'paySourcesFilter'] = pay_source_filter
+            'paySourcesFilter'
+        ] = source_filters
     if isinstance(theme_code, str):
-        wrapped_data.json['customFields']['theme_code'] = theme_code
+        wrapped_data.json['customFields']['themeCode'] = theme_code
     if not isinstance(theme_code, str) and pay_source_filter not in [
         'qw',
         'card',
@@ -226,10 +213,10 @@ def multiply_objects_parse(lst_of_objects, model):
         try:
             if isinstance(obj, dict):
                 obj: str
-                objects.append(model.parse_raw(obj))
+                objects.append(model.parse_obj(obj))
                 continue
             for detached_obj in obj:
-                objects.append(model.parse_raw(detached_obj))
+                objects.append(model.parse_obj(detached_obj))
         except ValidationError as ex:
             print(ex.json(indent=4))
     return objects
@@ -244,10 +231,22 @@ def simple_multiply_parse(lst_of_objects, model):
     """
     objects = []
     for obj in lst_of_objects:
-        objects.append(model.parse_raw(obj))
+        objects.append(model.parse_obj(obj))
     return objects
 
 
+def take_event_loop(set_debug: bool = False):
+    try:
+        loop = asyncio.get_running_loop()
+        if loop.is_closed():
+            raise RuntimeError()
+    except RuntimeError:
+        loop = asyncio.new_event_loop()
+        asyncio.set_event_loop(loop)
+    loop.set_debug(set_debug)
+    return loop
+
+
 def hmac_key(key, amount, status, bill_id, site_id):
     """
     Функция расшифровки подписи webhook
@@ -323,11 +322,10 @@ def allow_response_code(status_code):
     return wrap_func
 
 
-def qiwi_master_data(ph_number):
-    url = "https://edge.qiwi.com" + '/sinap/api/v2/terms/28004/payments'
-    payload = deepcopy(QIWI_MASTER)
+def qiwi_master_data(ph_number, data):
+    payload = deepcopy(data)
     payload["fields"]["account"] = ph_number
-    return url, payload
+    return payload
 
 
 def to_datetime(string_representation):
@@ -341,14 +339,14 @@ def to_datetime(string_representation):
         parsed = orjson.dumps(
             {'dt': string_representation}
         )
-        return Parser.parse_raw(parsed).dt
+        return Parser.parse_obj(parsed).dt
     except (ValidationError, orjson.JSONDecodeError) as ex:
         return ex.json(indent=4)
 
 
-def new_card_data(ph_number, order_id):
-    payload = deepcopy(QIWI_MASTER)
-    url = "https://edge.qiwi.com" + "/sinap/api/v2/terms/32064/payments"
+def new_card_data(ph_number, order_id, data):
+    payload = deepcopy(data)
+    url = "https://edge.qiwi.com" + "/sinap/test_api/v2/terms/32064/payments"
     payload["fields"].pop("vas_alias")
     payload["fields"].update(order_id=order_id)
     payload["fields"]["account"] = ph_number
@@ -381,18 +379,23 @@ def parse_amount(txn_type, txn):
 
 
 def check_params(amount_, amount, txn, transaction_type):
-    if amount_ >= amount:
-        if txn.direction == transaction_type:
-            return True
+    if amount is not None:
+        if amount_ >= amount:
+            if txn.direction == transaction_type:
+                return True
     return False
 
 
-def _run_forever_safe(loop) -> None:
+def run_forever_safe(loop) -> None:
     """ run a loop for ever and clean up after being stopped """
 
     loop.run_forever()
     # NOTE: loop.run_forever returns after calling loop.stop
 
+    safe_cancel(loop=loop)
+
+
+def safe_cancel(loop) -> None:
     # -- cancel all tasks and close the loop gracefully
 
     loop_tasks_all = asyncio.all_tasks(loop=loop)
@@ -438,8 +441,7 @@ class AdaptiveExecutor(futures.ThreadPoolExecutor):
 
 def _construct_all():
     """ Get or create new event loop """
-    loop = asyncio.new_event_loop()
-    asyncio.set_event_loop(loop)
+    loop = take_event_loop()
     executor = AdaptiveExecutor()
     loop.set_default_executor(executor)
     return loop, executor
@@ -463,17 +465,114 @@ def sync(func, *args, **kwargs):
 
     # construct an event loop and executor
     loop, executor = _construct_all()
-
     # Run our coroutine thread safe
     wrapped_future = asyncio.run_coroutine_threadsafe(
         func(*args, **kwargs),
         loop=loop
     )
     # Run loop.run_forever(), but do it safely
-    executor.submit(_run_forever_safe, loop)
+    executor.submit(run_forever_safe, loop)
     try:
         # Get result
         return _await_sync(wrapped_future)
     finally:
         # Cleanup
         _on_shutdown(executor, loop)
+
+
+def check_transaction(
+        transactions,
+        amount,
+        transaction_type,
+        sender,
+        comment
+):
+    for txn in transactions:
+        if float(txn.sum.amount) >= amount:
+            if txn.type == transaction_type:
+                if txn.comment == comment and txn.to_account == sender:
+                    return True
+                elif comment and sender:
+                    continue
+                elif txn.to_account == sender:
+                    return True
+                elif sender:
+                    continue
+                elif txn.comment == comment:
+                    return True
+    return False
+
+
+def parse_limits(response, model):
+    limits = {}
+    for code, limit in response.response_data.get("limits").items():
+        if not limit:
+            continue
+        limits.update({code: model.parse_obj(limit[0])})
+    return limits
+
+
+def override_error_messages(status_codes):
+    """
+    Function, which helps to override error message
+
+    :param status_codes: special dictionary
+    """
+
+    def functor(func):
+        @ft.wraps(func)
+        async def wrapper(*args, **kwargs):
+            from glQiwiApi import RequestError
+            try:
+                return await func(*args, **kwargs)
+            except RequestError as ex:
+                if int(ex.status_code) in status_codes.keys():
+                    error = status_codes.get(int(ex.status_code))
+                    ex = RequestError(
+                        message=error.get("message"),
+                        status_code=ex.status_code,
+                        json_info=error.get("json_info"),
+                        additional_info=ex.additional_info
+                    )
+                raise ex
+
+        return wrapper
+
+    return functor
+
+
+def check_api_method(api_method):
+    if not isinstance(api_method, str):
+        raise ValueError("Invalid type of api_method(must  be string)")
+
+
+def check_dates_for_statistic_request(start_date, end_date):
+    first_expression = isinstance(
+        start_date, datetime.datetime
+    ) and isinstance(end_date, datetime.datetime)
+    second_expression = isinstance(
+        start_date, datetime.timedelta
+    ) and isinstance(end_date, datetime.timedelta)
+    if first_expression or second_expression:
+        delta: datetime.timedelta = end_date - start_date
+        if delta.days > 90:
+            raise ValueError(
+                'Максимальный период для выгрузки'
+                ' статистики - 90 календарных дней.'
+            )
+    else:
+        raise ValueError(
+            'Вы передали значения начальной '
+            'и конечной даты в неправильном формате.'
+        )
+
+
+async def save_file(dir_path, file_name, data):
+    if isinstance(dir_path, str):
+        dir_path = pathlib.Path(dir_path)
+    if not dir_path.is_dir():
+        raise RuntimeError("Invalid path to save, its not directory!")
+    dir_path: pathlib.Path
+    path_to_file = dir_path / (file_name + '.pdf')
+    async with aiofiles.open(path_to_file, 'wb') as file:
+        return await file.write(data)
